@@ -14,7 +14,7 @@ Supported Libaries
 ==================
 
 ``wsgi_intercept`` works with a variety of HTTP clients in Python 2.7,
-3.3 and beyond, and in pypy.
+3.5 and beyond, and in pypy.
 
 * urllib2
 * urllib.request
@@ -115,8 +115,8 @@ it into all of the *other* Python Web testing frameworks.
 The Python 2 version of wsgi-intercept was the result. Kumar McMillan
 later took over maintenance.
 
-The current version is tested with Python 2.7, 3.3, 3.4, 3.5, 3.6, and pypy
-and was assembled by `Chris Dent`_. Testing and documentation improvements
+The current version is tested with Python 2.7, 3.5-3.8, and pypy and pypy3.
+It was assembled by `Chris Dent`_. Testing and documentation improvements
 from `Sasha Hart`_.
 
 .. _"best Web testing framework":
@@ -201,6 +201,7 @@ def remove_wsgi_intercept(*args):
         key = (args[0], args[1])
         if key in _wsgi_intercept:
             del _wsgi_intercept[key]
+    return len(_wsgi_intercept)
 
 
 #
@@ -313,7 +314,7 @@ def make_environ(inp, host, port, script_name):
         "wsgi.version": (1, 0),
         "wsgi.url_scheme": "http",
         "wsgi.input": inp,  # to read for POSTs
-        "wsgi.errors": BytesIO(),
+        "wsgi.errors": sys.stderr,
         "wsgi.multithread": 0,
         "wsgi.multiprocess": 0,
         "wsgi.run_once": 0,
@@ -450,25 +451,6 @@ class wsgi_fake_socket:
             raise WSGIAppError(error, sys.exc_info())
         self.result = iter(app_result)
 
-        # send the headers
-
-        for k, v in self.headers:
-            if STRICT_RESPONSE_HEADERS:
-                if not (isinstance(k, str) and isinstance(v, str)):
-                    raise TypeError(
-                        "Header has a key '%s' or value '%s' "
-                        "which is not a native str." % (k, v))
-            try:
-                k = k.encode('ISO-8859-1')
-            except AttributeError:
-                pass
-            try:
-                v = v.encode('ISO-8859-1')
-            except AttributeError:
-                pass
-            self.output.write(k + b': ' + v + b"\n")
-        self.output.write(b'\n')
-
         ###
 
         # read all of the results.  the trick here is to get the *first*
@@ -484,6 +466,25 @@ class wsgi_fake_socket:
                 generator_data = next(self.result)
 
             finally:
+                # send the headers
+
+                for k, v in self.headers:
+                    if STRICT_RESPONSE_HEADERS:
+                        if not (isinstance(k, str) and isinstance(v, str)):
+                            raise TypeError(
+                                "Header has a key '%s' or value '%s' "
+                                "which is not a native str." % (k, v))
+                    try:
+                        k = k.encode('ISO-8859-1')
+                    except AttributeError:
+                        pass
+                    try:
+                        v = v.encode('ISO-8859-1')
+                    except AttributeError:
+                        pass
+                    self.output.write(k + b': ' + v + b"\n")
+                self.output.write(b'\n')
+
                 for data in self.write_results:
                     self.output.write(data)
 
@@ -622,6 +623,24 @@ class WSGI_HTTPSConnection(HTTPSConnection, WSGI_HTTPConnection):
             else:
                 try:
                     import ssl
+                    if hasattr(self, '_context'):
+                        self._context.check_hostname = self.assert_hostname
+                        self._check_hostname = self.assert_hostname     # Py3.6
+                        if hasattr(ssl, 'VerifyMode'):
+                            # Support for Python3.6 and higher
+                            if isinstance(self.cert_reqs, ssl.VerifyMode):
+                                self._context.verify_mode = self.cert_reqs
+                            else:
+                                self._context.verify_mode = ssl.VerifyMode[
+                                    self.cert_reqs]
+                        elif isinstance(self.cert_reqs, six.string_types):
+                            # Support for Python3.5 and below
+                            self._context.verify_mode = getattr(ssl,
+                                    self.cert_reqs,
+                                    self._context.verify_mode)
+                        else:
+                            self._context.verify_mode = self.cert_reqs
+
                     if not hasattr(self, 'key_file'):
                         self.key_file = None
                     if not hasattr(self, 'cert_file'):
@@ -639,7 +658,8 @@ class WSGI_HTTPSConnection(HTTPSConnection, WSGI_HTTPConnection):
                             else:
                                 self._check_hostname = self.check_hostname
                 except (ImportError, AttributeError):
-                    pass
+                    import traceback
+                    traceback.print_exc()
                 HTTPSConnection.connect(self)
 
         except Exception:
